@@ -34,6 +34,28 @@ class Tag(AWSHelperFn):
         return self.data
 
 
+class Tags(AWSHelperFn):
+    defaultPropagateAtLaunch = True
+    manyType = [type([]), type(())]
+
+    def __init__(self, **kwargs):
+        self.tags = []
+        for k, v in sorted(kwargs.iteritems()):
+            if type(v) in self.manyType:
+                propagate = str(v[1]).lower()
+                v = v[0]
+            else:
+                propagate = str(self.defaultPropagateAtLaunch).lower()
+            self.tags.append({
+                'Key': k,
+                'Value': v,
+                'PropagateAtLaunch': propagate,
+            })
+
+    def JSONrepr(self):
+        return self.tags
+
+
 class NotificationConfiguration(AWSProperty):
     props = {
         'TopicARN': (basestring, True),
@@ -48,8 +70,35 @@ class MetricsCollection(AWSProperty):
     }
 
 
+class Metadata(AWSHelperFn):
+    def __init__(self, init, authentication=None):
+        self.validate(init, authentication)
+        # get keys and values from init and authentication
+        # safe to use cause its always one key
+        initKey, initValue = init.data.popitem()
+        self.data = {initKey: initValue}
+        if authentication:
+            authKey, authValue = authentication.data.popitem()
+            self.data[authKey] = authValue
+
+    def validate(self, init, authentication):
+        if not isinstance(init, cloudformation.Init):
+            raise ValueError(
+                'init must be of type cloudformation.Init'
+            )
+
+        is_instance = isinstance(authentication, cloudformation.Authentication)
+        if authentication and not is_instance:
+            raise ValueError(
+                'authentication must be of type cloudformation.Authentication'
+            )
+
+    def JSONrepr(self):
+        return self.data
+
+
 class AutoScalingGroup(AWSObject):
-    type = "AWS::AutoScaling::AutoScalingGroup"
+    resource_type = "AWS::AutoScaling::AutoScalingGroup"
 
     props = {
         'AvailabilityZones': (list, True),
@@ -90,7 +139,7 @@ class AutoScalingGroup(AWSObject):
 
 
 class LaunchConfiguration(AWSObject):
-    type = "AWS::AutoScaling::LaunchConfiguration"
+    resource_type = "AWS::AutoScaling::LaunchConfiguration"
 
     props = {
         'AssociatePublicIpAddress': (boolean, False),
@@ -103,7 +152,7 @@ class LaunchConfiguration(AWSObject):
         'InstanceType': (basestring, True),
         'KernelId': (basestring, False),
         'KeyName': (basestring, False),
-        'Metadata': (cloudformation.Init, False),
+        'Metadata': (Metadata, False),
         'RamDiskId': (basestring, False),
         'SecurityGroups': (list, False),
         'SpotPrice': (basestring, False),
@@ -112,7 +161,7 @@ class LaunchConfiguration(AWSObject):
 
 
 class ScalingPolicy(AWSObject):
-    type = "AWS::AutoScaling::ScalingPolicy"
+    resource_type = "AWS::AutoScaling::ScalingPolicy"
 
     props = {
         'AdjustmentType': (basestring, True),
@@ -123,7 +172,7 @@ class ScalingPolicy(AWSObject):
 
 
 class ScheduledAction(AWSObject):
-    type = "AWS::AutoScaling::ScheduledAction"
+    resource_type = "AWS::AutoScaling::ScheduledAction"
 
     props = {
         'AutoScalingGroupName': (basestring, True),
@@ -137,7 +186,7 @@ class ScheduledAction(AWSObject):
 
 
 class Trigger(AWSObject):
-    type = "AWS::AutoScaling::Trigger"
+    resource_type = "AWS::AutoScaling::Trigger"
 
     props = {
         'AutoScalingGroupName': (basestring, True),
