@@ -6,6 +6,7 @@ AP_NORTHEAST_1 = 'ap-northeast-1'
 AP_SOUTHEAST_1 = 'ap-southeast-1'
 AP_SOUTHEAST_2 = 'ap-southeast-2'
 EU_WEST_1 = 'eu-west-1'
+EU_CENTRAL_1 = 'eu-central-1'
 SA_EAST_1 = 'sa-east-1'
 US_EAST_1 = 'us-east-1'
 US_WEST_1 = 'us-west-1'
@@ -29,6 +30,9 @@ EU_WEST_1A = 'eu-west-1a'
 EU_WEST_1B = 'eu-west-1b'
 EU_WEST_1C = 'eu-west-1c'
 
+EU_CENTRAL_1A = 'eu-central-1a'
+EU_CENTRAL_1B = 'eu-central-1b'
+
 SA_EAST_1A = 'sa-east-1a'
 SA_EAST_1B = 'sa-east-1b'
 
