@@ -59,6 +59,12 @@ class ConnectionDrainingPolicy(AWSProperty):
     }
 
 
+class ConnectionSettings(AWSProperty):
+    props = {
+        'IdleTimeout': (int, True),
+    }
+
+
 class AccessLoggingPolicy(AWSProperty):
     props = {
         'EmitInterval': (int, False),
@@ -69,13 +75,14 @@ class AccessLoggingPolicy(AWSProperty):
 
 
 class LoadBalancer(AWSObject):
-    type = "AWS::ElasticLoadBalancing::LoadBalancer"
+    resource_type = "AWS::ElasticLoadBalancing::LoadBalancer"
 
     props = {
         'AccessLoggingPolicy': (AccessLoggingPolicy, False),
         'AppCookieStickinessPolicy': (list, False),
         'AvailabilityZones': (list, False),
         'ConnectionDrainingPolicy': (ConnectionDrainingPolicy, False),
+        'ConnectionSettings': (ConnectionSettings, False),
         'CrossZone': (boolean, False),
         'HealthCheck': (HealthCheck, False),
         'Instances': (list, False),
