@@ -19,7 +19,7 @@ class Subscription(AWSProperty):
 
 
 class TopicPolicy(AWSObject):
-    type = "AWS::SNS::TopicPolicy"
+    resource_type = "AWS::SNS::TopicPolicy"
 
     props = {
         'PolicyDocument': (policytypes, True),
@@ -28,7 +28,7 @@ class TopicPolicy(AWSObject):
 
 
 class Topic(AWSObject):
-    type = "AWS::SNS::Topic"
+    resource_type = "AWS::SNS::Topic"
 
     props = {
         'DisplayName': (basestring, False),
